@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef COLLECTIONEXPIRYWIDGET_H
-#define COLLECTIONEXPIRYWIDGET_H
+#pragma once
 #include "mailcommon_export.h"
 
 #include <MailCommon/ExpireCollectionAttribute>
@@ -14,7 +13,6 @@ class QCheckBox;
 class KPluralHandlingSpinBox;
 class QRadioButton;
 class QPushButton;
-class KJob;
 namespace MailCommon
 {
 class FolderRequester;
@@ -52,18 +50,13 @@ private:
     Q_REQUIRED_RESULT bool validateExpireFolder(bool expireNow);
     Q_REQUIRED_RESULT MailCommon::ExpireCollectionAttribute *assignFolderAttribute(Akonadi::Collection &collection, bool &expireNow);
     void slotChanged();
-    void slotUpdateControls();
-    QCheckBox *mExpireReadMailCB = nullptr;
-    KPluralHandlingSpinBox *mExpireReadMailSB = nullptr;
-    QCheckBox *mExpireUnreadMailCB = nullptr;
-    KPluralHandlingSpinBox *mExpireUnreadMailSB = nullptr;
+    KPluralHandlingSpinBox *const mExpireReadMailSB;
+    KPluralHandlingSpinBox *const mExpireUnreadMailSB;
     QRadioButton *mMoveToRB = nullptr;
-    FolderRequester *mFolderSelector = nullptr;
+    FolderRequester *const mFolderSelector;
     QRadioButton *mDeletePermanentlyRB = nullptr;
-    QPushButton *mExpireNowPB = nullptr;
-    QCheckBox *mExpireMailWithInvalidDateCB = nullptr;
+    QPushButton *const mExpireNowPB;
+    QCheckBox *const mExpireMailWithInvalidDateCB;
 };
 }
 MAILCOMMON_EXPORT QDebug operator<<(QDebug d, const MailCommon::CollectionExpirySettings &t);
-
-#endif // COLLECTIONEXPIRYWIDGET_H
