@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INVALIDFILTERINFOWIDGET_H
-#define INVALIDFILTERINFOWIDGET_H
+#pragma once
 
 #include "mailcommon_private_export.h"
 #include <KMessageWidget>
@@ -16,10 +15,9 @@ class MAILCOMMON_TESTS_EXPORT InvalidFilterInfoWidget : public KMessageWidget
     Q_OBJECT
 public:
     explicit InvalidFilterInfoWidget(QWidget *parent = nullptr);
-    ~InvalidFilterInfoWidget();
+    ~InvalidFilterInfoWidget() override;
 public Q_SLOTS:
     void slotShowDetails(const QString &details);
 };
 }
 
-#endif // INVALIDFILTERINFOWIDGET_H
