@@ -6,17 +6,19 @@
 */
 
 #include "entitycollectionorderproxymodel.h"
+#include "hierarchicalfoldermatcher_p.h"
 #include "kernel/mailkernel.h"
 #include "mailcommon_debug.h"
 #include "util/mailutil.h"
-#include <AgentManager>
+#include <Akonadi/AgentManager>
+#include <Akonadi/Collection>
+#include <Akonadi/EntityTreeModel>
 #include <Akonadi/KMime/SpecialMailCollections>
-#include <Collection>
-#include <EntityTreeModel>
 
-namespace MailCommon
-{
-class Q_DECL_HIDDEN EntityCollectionOrderProxyModel::EntityCollectionOrderProxyModelPrivate
+#include <QRegularExpression>
+
+using namespace MailCommon;
+class Q_DECL_HIDDEN MailCommon::EntityCollectionOrderProxyModel::EntityCollectionOrderProxyModelPrivate
 {
 public:
     EntityCollectionOrderProxyModelPrivate()
@@ -71,6 +73,7 @@ public:
 
     QMap<Akonadi::Collection::Id, int> collectionRanks;
     QStringList topLevelOrder;
+    HierarchicalFolderMatcher matcher;
     bool manualSortingActive = false;
 };
 
@@ -94,7 +97,6 @@ EntityCollectionOrderProxyModel::~EntityCollectionOrderProxyModel()
     if (d->manualSortingActive) {
         saveOrder();
     }
-    delete d;
 }
 
 void EntityCollectionOrderProxyModel::slotSpecialCollectionsChanged()
@@ -156,4 +158,18 @@ bool EntityCollectionOrderProxyModel::isManualSortingActive() const
 {
     return d->manualSortingActive;
 }
+
+void EntityCollectionOrderProxyModel::setFolderMatcher(const HierarchicalFolderMatcher &matcher)
+{
+    d->matcher = matcher;
+    invalidateFilter();
+}
+
+bool EntityCollectionOrderProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
+{
+    if (d->matcher.isNull()) {
+        return EntityOrderProxyModel::filterAcceptsRow(sourceRow, sourceParent);
+    }
+    const QModelIndex sourceIndex = sourceModel()->index(sourceRow, filterKeyColumn(), sourceParent);
+    return d->matcher.matches(sourceModel(), sourceIndex, filterRole());
 }
