@@ -1,39 +1,28 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FOLDERTREEVIEW_H
-#define MAILCOMMON_FOLDERTREEVIEW_H
+#pragma once
 
-#include "mailcommon_export.h"
 #include "foldertreewidget.h"
 #include "mailcommon/mailutil.h"
+#include "mailcommon_export.h"
 
-#include <EntityTreeView>
-#include <Collection>
+#include <Akonadi/Collection>
+#include <Akonadi/EntityTreeView>
 
 class QMouseEvent;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class CollectionStatisticsDelegate;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * This is an enhanced EntityTreeView specially suited for the folders in KMail's
  * main folder widget.
@@ -68,11 +57,9 @@ public:
     void updatePalette();
 
     void keyboardSearch(const QString &) override;
+
 protected:
-    enum Move {
-        Next = 0,
-        Previous = 1
-    };
+    enum Move { Next = 0, Previous = 1 };
 
     void init(bool showUnreadCount);
     void selectModelIndex(const QModelIndex &);
@@ -105,10 +92,7 @@ Q_SIGNALS:
     void newTabRequested(bool);
 
 private:
-    enum SearchDirection {
-        ForwardSearch,
-        BackwardSearch
-    };
+    enum SearchDirection { ForwardSearch, BackwardSearch };
 
     QModelIndex indexAbove(const QModelIndex &current) const;
     QModelIndex indexBelow(const QModelIndex &current) const;
@@ -127,4 +111,3 @@ private:
 };
 }
 
-#endif
