@@ -14,6 +14,7 @@ using MailCommon::RuleWidgetHandlerManager;
 #include <KLocalizedString>
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <QButtonGroup>
+#include <QFormLayout>
 #include <QHBoxLayout>
 #include <QIcon>
 #include <QLineEdit>
@@ -135,7 +136,7 @@ void SearchRuleWidget::setPatternEditOptions(SearchPatternEdit::SearchPatternEdi
 void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
 {
     auto hlay = new QHBoxLayout(this);
-    hlay->setContentsMargins(0, 0, 0, 0);
+    hlay->setContentsMargins({});
 
     // initialize the header field combo box
     mRuleField = new KComboBox(this);
@@ -557,7 +558,6 @@ void SearchRuleWidgetLister::regenerateRuleListFromWidgets()
 
 SearchPatternEdit::SearchPatternEdit(QWidget *parent, SearchPatternEditOptions options, SearchModeType modeType)
     : QWidget(parent)
-    , mAllMessageRBtn(nullptr)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     setObjectName(QStringLiteral("SearchPatternEdit"));
@@ -580,8 +580,8 @@ void SearchPatternEdit::setPatternEditOptions(SearchPatternEdit::SearchPatternEd
 
 void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeType modeType)
 {
-    auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto layout = new QFormLayout(this);
+    layout->setContentsMargins({});
 
     const bool matchAllMessages = (options & MailCommon::SearchPatternEdit::MatchAllMessages);
     //------------the radio buttons
@@ -599,10 +599,10 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
         mAllMessageRBtn->setObjectName(QStringLiteral("mAllMessageRBtn"));
         mAllMessageRBtn->setChecked(false);
     }
-    layout->addWidget(mAllRBtn);
-    layout->addWidget(mAnyRBtn);
+    layout->addRow(i18n("Filter criteria:"), mAllRBtn);
+    layout->addRow(QString(), mAnyRBtn);
     if (matchAllMessages) {
-        layout->addWidget(mAllMessageRBtn);
+        layout->addRow(QString(), mAllMessageRBtn);
     }
 
     auto bg = new QButtonGroup(this);
@@ -613,7 +613,7 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
     }
 
     //------------connect a few signals
-    connect(bg, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &SearchPatternEdit::slotRadioClicked);
+    connect(bg, &QButtonGroup::buttonClicked, this, &SearchPatternEdit::slotRadioClicked);
 
     //------------the list of SearchRuleWidget's
     mRuleLister = new SearchRuleWidgetLister(this, options, modeType);
@@ -632,11 +632,11 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
         qCDebug(MAILCOMMON_LOG) << "No first SearchRuleWidget, though slotClear() has been called!";
     }
 
-    connect(mRuleLister, QOverload<QWidget *>::of(&SearchRuleWidgetLister::widgetAdded), this, &SearchPatternEdit::slotRuleAdded);
-    connect(mRuleLister, QOverload<>::of(&SearchRuleWidgetLister::widgetRemoved), this, &SearchPatternEdit::patternChanged);
+    connect(mRuleLister, qOverload<QWidget *>(&SearchRuleWidgetLister::widgetAdded), this, &SearchPatternEdit::slotRuleAdded);
+    connect(mRuleLister, qOverload<>(&SearchRuleWidgetLister::widgetRemoved), this, &SearchPatternEdit::patternChanged);
     connect(mRuleLister, &KPIM::KWidgetLister::clearWidgets, this, &SearchPatternEdit::patternChanged);
 
-    layout->addWidget(mRuleLister);
+    layout->addRow(mRuleLister);
 }
 
 void SearchPatternEdit::setSearchPattern(SearchPattern *aPattern)
