@@ -4,11 +4,10 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SEARCHRULEDATE_H
-#define SEARCHRULEDATE_H
+#pragma once
 
 #include "searchpattern.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 namespace MailCommon
 {
 class SearchRuleDate : public SearchRule
@@ -55,4 +54,3 @@ public:
 };
 }
 
-#endif // SEARCHRULEDATE_H
