@@ -6,20 +6,16 @@
 
 #include "encryptionwidgethandler.h"
 #include <QComboBox>
-#include <QStackedWidget>
 #include <QLabel>
+#include <QStackedWidget>
 
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
     const char *displayName;
-} EncryptionFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not")      }
-};
-static const int EncryptionFunctionCount
-    = sizeof(EncryptionFunctions) / sizeof(*EncryptionFunctions);
+} EncryptionFunctions[] = {{SearchRule::FuncEquals, I18N_NOOP("is")}, {SearchRule::FuncNotEqual, I18N_NOOP("is not")}};
+static const int EncryptionFunctionCount = sizeof(EncryptionFunctions) / sizeof(*EncryptionFunctions);
 
 EncryptionWidgetHandler::EncryptionWidgetHandler()
     : RuleWidgetHandler()
@@ -32,7 +28,7 @@ EncryptionWidgetHandler::~EncryptionWidgetHandler()
 
 QWidget *EncryptionWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
-    Q_UNUSED(isBalooSearch);
+    Q_UNUSED(isBalooSearch)
 
     if (number != 0) {
         return nullptr;
@@ -45,14 +41,13 @@ QWidget *EncryptionWidgetHandler::createFunctionWidget(int number, QStackedWidge
         combo->addItem(i18n(EncryptionFunctions[i].displayName));
     }
     combo->adjustSize();
-    QObject::connect(combo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(combo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return combo;
 }
 
 QWidget *EncryptionWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
-    Q_UNUSED(receiver);
+    Q_UNUSED(receiver)
 
     if (number != 0) {
         return nullptr;
@@ -79,8 +74,8 @@ SearchRule::Function EncryptionWidgetHandler::function(const QByteArray &field,
 
 QString EncryptionWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
-    Q_UNUSED(functionStack);
-    Q_UNUSED(valueStack);
+    Q_UNUSED(functionStack)
+    Q_UNUSED(valueStack)
     if (!handlesField(field)) {
         return QString();
     }
@@ -89,8 +84,8 @@ QString EncryptionWidgetHandler::value(const QByteArray &field, const QStackedWi
 
 QString EncryptionWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
-    Q_UNUSED(functionStack);
-    Q_UNUSED(valueStack);
+    Q_UNUSED(functionStack)
+    Q_UNUSED(valueStack)
     if (!handlesField(field)) {
         return QString();
     }
@@ -112,12 +107,12 @@ void EncryptionWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidge
         combo->blockSignals(blocked);
     }
 
-    Q_UNUSED(valueStack);
+    Q_UNUSED(valueStack)
 }
 
 bool EncryptionWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool isBalooSearch) const
 {
-    Q_UNUSED(isBalooSearch);
+    Q_UNUSED(isBalooSearch)
     if (!rule || !handlesField(rule->field())) {
         reset(functionStack, valueStack);
         return false;
